%global srcname pebl

Name:		python-%{srcname}
Version:	1.0.2
Release:	13%{?dist}
Summary:	PEBL: Python Environment for Bayesian Learning

Group:		Development/Languages
License:	MIT
URL:		http://code.google.com/p/pebl-project/
Source0:	http://pebl-project.googlecode.com/files/%{srcname}-%{version}.tar.gz
Source1:	README.Fedora
# Fixes the generation of Sphinx documentation during the %%build phase
Patch0:		pebl-1.0.2-sphinx_building.patch

BuildRequires:	python2-devel
BuildRequires:	numpy
BuildRequires:	python-setuptools
# The BuildRequires below are needed for building the Sphinx documentation
BuildRequires:	python-sphinx
BuildRequires:	pydot
# The BuildRequires below are needed for performing the unit tests
BuildRequires:	python-matplotlib
BuildRequires:	graphviz
BuildRequires:	python-simplejson

Requires:	numpy
Requires:	pydot
# The Requires below are optional, needed for certain types of functionality
# Requires for creating HTML reports of Pebl results
Requires:	python-matplotlib
Requires:	graphviz
Requires:	python-simplejson
# Requires for the Amazon EC2 Task Controller
Requires:	python-boto

# prevent rpm's auto-generated provides mechanism to include Pebl's private
# libraries
%{?filter_setup:
%filter_provides_in %{python_sitearch}/.*\.so$ 
%filter_setup
}

%description
Pebl is a python library and command line application for learning the
structure of a Bayesian network given prior knowledge and observations.
Pebl includes the following features:
- can learn with observational and interventional data
- handles missing values and hidden variables using exact and heuristic methods
- provides several learning algorithms; makes creating new ones simple
- has facilities for transparent parallel execution using several cluster/grid
resources
- calculates edge marginals and consensus networks
- presents results in a variety of formats 


%prep
%setup -q -n %{srcname}-%{version}
cp %{SOURCE1} .
%patch0 -p1 -b .sphinx_building


%build
CFLAGS="%{optflags}" %{__python} setup.py build build_sphinx


%install
# --root %%{buildroot} makes the package install with a single, expanded
# directory in %%{python_sitelib} and a separate egginfo directory.
%{__python} setup.py install --skip-build --root %{buildroot}

# remove the files needed for performing unittests and manual tests
rm -r %{buildroot}/%{python_sitearch}/%{srcname}/test
rm -r %{buildroot}/%{python_sitearch}/%{srcname}/test.manual
# delete unnecessary source files that rpmlint complains about
rm %{buildroot}/%{python_sitearch}/%{srcname}/_cpd.c
rm %{buildroot}/%{python_sitearch}/%{srcname}/_network.c
# delete a hidden file that rpmlint complains about
rm docs/build/html/.buildinfo
# replace the dangling relative symlink that rpmlint complains about with
# the actual file it points to
mv docs/src/install.rst INSTALL.txt

# Note: Currently, 219 unit tests are run, 1 fails and 8 have errors.
# Upstream bug report about this:
# http://code.google.com/p/pebl-project/issues/detail?id=45
%check
%{__python} setup.py test || :


%files
%doc INSTALL.txt LICENSE.txt README.txt README.Fedora
%doc docs/build/html
%{_bindir}/%{srcname}
%{python_sitearch}/%{srcname}/
%{python_sitearch}/%{srcname}-*.egg-info


%changelog
* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Oct 15 2011 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-7
- rebuilt with new pydot (1.0.25-2) which fixes some of the unit test errors

* Sun Oct 09 2011 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-6
- implemented fixes suggested by Thomas Spura:
  - improved the Provides filtering of Pebl's private libraries
  - enabled unit tests in the %%check section and noted how many are currently
    failing

* Sat Oct 08 2011 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-5
- removed the definition of python_sitelib and python_sitearch macros as they
  are not needed for F-13 and above
- removed the %%clean section as it is not needed for F-13 and above
- removed the %%defattr at the beginning of the %%files section as it is not
  needed anymore
- removed an obsolete conditional BuildRequires for legacy Fedora releases
- added a patch that fixes the generation of Sphinx documentation during the
  %%build phase (provided by Toshio Ernie Kuratomi)
- added new BuildRequires needed for building the Sphinx documentation

* Tue Jun 15 2010 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-4
- applied a patch from Toshio Ernie Kuratomi, which:
    - adds BuildRequire on numpy
    - changes the filter string to filter out the private shared .so's

* Thu Jun 03 2010 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-3
- updated the spec file to conform to the newest Python packaging guidelines
- implemented fixes suggested by Thomas Spura:
    - disabled rpmbuild's internal dependency generator to prevent erroneous
      provides for _cpd.so and _network.so
    - removed the files needed for performing unittests and manual tests from
      final rpm

* Thu Apr 01 2010 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-2
- added README.Fedora which explains, why XGrid and IPython1 task controllers
  are not working at the moment
- removed files that rpmlint complains about
- replaced a dangling relative symlink with the actual file it points to

* Tue Jan 26 2010 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.2-1
- update to version 1.0.2
- dropped pebl-1.0.1-build_sphinx.patch (now included upstream)
- implemented fixes suggested by Thomas Spura:
    - dropped Requires: python
    - changed BuildRequires from python-setuptools-devel to python-setuptools
    - fixed %%files section to notice, when the eggs can't be built
    - added %%check section, which runs the unittests
    - added missing Requires: numpy, pydot, python-matplotlib, graphviz,
      python-simplejson, python-boto

* Mon Jan 04 2010 Tadej Janež <tadej.janez@tadej.hicsalta.si> 1.0.1-1
- initial package

